'use strict';

const fs = require('fs');
const process = require('process');
const kolorist = require('kolorist');
const consola = require('consola');
const os = require('os');
const path = require('path');

const logger = consola.createConsola().withTag("s-info");
function showRuntimeInfo() {
  logger.log(`node: ${kolorist.lightGreen(process.version)}`);
  logger.log(
    `platform: ${kolorist.lightGreen(os.version())}`
  );
}
const CONFIG_FILE_SUFFIX = [
  ".js",
  ".mjs",
  ".ts",
  ".cjs",
  ".mts",
  ".cts"
];
async function showProjectType() {
  for (const SUFFIX of CONFIG_FILE_SUFFIX) {
    if (fs.existsSync(path.join("vite.config", SUFFIX))) {
      logger.log(
        `type: ${kolorist.lightGreen("vite")}`
      );
      return;
    }
    if (fs.existsSync(path.join("nuxt.config", SUFFIX))) {
      logger.log(
        `type: ${kolorist.lightGreen("nuxt")}`
      );
      return;
    }
  }
}
async function separate(fn) {
  console.log();
  await fn();
  console.log();
}

exports.CONFIG_FILE_SUFFIX = CONFIG_FILE_SUFFIX;
exports.separate = separate;
exports.showProjectType = showProjectType;
exports.showRuntimeInfo = showRuntimeInfo;
